# Karbon

Karbon tracks background mouse events and turns them into artistic values!

## Installation

```sh
pip install karbon
```

## Running

```sh
python -m karbon
```

### After few hours later...

<div align="center">
  <img src="https://raw.githubusercontent.com/furkanonder/karbon/master/assets/examples/example.jpg" width=900px />
</div>

## Snapshots

You can find the snapshots in the `.karbon_snapshots` folder within your home
directory.
